@@ -5,33 +5,40 @@
 #include <JLBFont.h>
 #include <JGui.h>
 #include "DeckMenu.h"
+#include "SimpleMenuItem.h"
 
 using std::string;
 
-class DeckMenuItem: public JGuiObject
+class DeckMenuItem: public SimpleMenuItem
 {
 private:
-    bool mHasFocus;
     bool mScrollEnabled;
     bool mDisplayInitialized;
-
+    
     DeckMenu* parent;
-    int fontId;
-    string mText;
     float mTitleResetWidth;
-    static float mYOffset;
+    
+protected:
+    virtual void checkUserClick();
 
 public:
     string imageFilename;
     string desc;
     float mScrollerOffset;
     DeckMetaData *meta;
+    
+    virtual bool hasFocus();
 
-    float mX;
-    float mY;
-
-    void Relocate(float x, float y);
-    float GetWidth();
+    virtual void Relocate(float x, float y);
+    virtual float GetWidth();
+    virtual void Render();
+    virtual void Update(float dt);
+    
+    virtual bool getTopLeft(float& top, float& left)
+    {
+        return SimpleMenuItem::getTopLeft(top, left);
+    }
+    
     string GetText()
     {
         return mText;
@@ -40,25 +47,15 @@ public:
     {
         return desc;
     }
-    bool hasFocus();
 
     DeckMenuItem(DeckMenu* _parent, int id, int fontId, string text, float x, float y, bool hasFocus = false, bool autoTranslate = false, DeckMetaData *meta = NULL);
     ~DeckMenuItem();
-
-    void RenderWithOffset(float yOffset);
-    virtual void Render();
-    virtual void Update(float dt);
     virtual void Entering();
     virtual bool Leaving(JButton key);
     virtual bool ButtonPressed();
     virtual ostream& toString(ostream& out) const;
-    virtual bool getTopLeft(float& top, float& left)
-    {
-        top = mY + mYOffset;
-        left = mX;
-        return true;
-    }
-    ;
+    virtual void RenderWithOffset(float yOffset);
+
 };
 
 #endif
