@@ -24,35 +24,26 @@
 #ifdef NETWORK_SUPPORT
 #include "JNetwork.h"
 #endif //NETWORK_SUPPORT
+#include "GameObserver.h"
 
+/* Wagic versions */
+#define WAGIC_VERSION_MAJOR     0
+#define WAGIC_VERSION_MEDIUM    17
+#define WAGIC_VERSION_MINOR     1
+
+#define VERSION_DOT(a, b, c) a ##.## b ##.## c
+#define VERSION_WITHOUT_DOT(a, b, c) a ## b ## c
+#define VERSION_GAME(a, b, c) VERSION_DOT(a, b, c)
+#define VERSION_FILE(a, b, c) VERSION_WITHOUT_DOT(a, b, c)
+#define VERSION_TOSTRING(a) #a
+#define VERSION_STRINGIFY(a) VERSION_TOSTRING(a)
+
+#define WAGIC_VERSION           VERSION_GAME(WAGIC_VERSION_MAJOR, WAGIC_VERSION_MEDIUM, WAGIC_VERSION_MINOR)
+#define WAGIC_RESOURCE_VERSION  VERSION_FILE(WAGIC_VERSION_MAJOR, WAGIC_VERSION_MEDIUM, WAGIC_VERSION_MINOR)
+#define WAGIC_VERSION_STRING    VERSION_STRINGIFY(WAGIC_VERSION)
+#define WAGIC_RESOURCE_NAME     "core_" VERSION_STRINGIFY(WAGIC_RESOURCE_VERSION) ".zip"
 
 class Rules;
-enum
-{
-    PLAYER_TYPE_CPU = 0,
-    PLAYER_TYPE_HUMAN=1,
-    PLAYER_TYPE_TESTSUITE=2,
-#ifdef NETWORK_SUPPORT
-    PLAYER_TYPE_REMOTE=3
-#endif //NETWORK_SUPPORT
-};
-
-enum
-{
-    GAME_TYPE_CLASSIC,
-    GAME_TYPE_MOMIR,
-    GAME_TYPE_RANDOM1,
-    GAME_TYPE_RANDOM2,
-    GAME_TYPE_STORY,
-    GAME_TYPE_DEMO,
-	GAME_TYPE_STONEHEWER,
-	GAME_TYPE_HERMIT,
-
-#ifdef NETWORK_SUPPORT
-    GAME_TYPE_SLAVE,
-#endif //NETWORK_SUPPORT
-};
-
 class MTGAllCards;
 class TransitionBase;
 
@@ -72,7 +63,7 @@ private:
     GameState* mGameStates[GAME_STATE_MAX];
 public:
 
-    int gameType;
+    GameType gameType;
     Rules * rules;
     CardEffect *effect;
 #ifdef NETWORK_SUPPORT
@@ -93,18 +84,20 @@ public:
 
     void LoadGameStates();
     void SetNextState(int state);
+    void SetCurrentState(GameState * state);
     void DoTransition(int trans, int tostate, float dur = -1, bool animonly = false);
     void DoAnimation(int trans, float dur = -1);
     static hgeParticleSystem * Particles[6];
-    static int HasMusic;
+    static bool HasMusic;
     static string systemError;
     static JMusic* music;
     static string currentMusicFile;
-    static void playMusic(string filename, bool loop = true);
-    static int players[2];
+    static void playMusic(string filename = "", bool loop = true);
+    static void stopMusic();
+    static PlayerType players[2];
 
 };
 
-extern JQuadPtr manaIcons[7];
+extern vector<JQuadPtr> manaIcons;
 
 #endif
