@@ -7,6 +7,55 @@ const float DEFAULT_TEXT_FONT_SCALE = 1.0f;
 
 #include <string>
 using std::string;
+
+typedef enum
+{
+    GAME_TYPE_CLASSIC,
+    GAME_TYPE_MOMIR,
+    GAME_TYPE_RANDOM1,
+    GAME_TYPE_RANDOM2,
+    GAME_TYPE_STORY,
+    GAME_TYPE_DEMO,
+    GAME_TYPE_STONEHEWER,
+    GAME_TYPE_HERMIT,
+
+#ifdef NETWORK_SUPPORT
+    GAME_TYPE_SLAVE,
+#endif //NETWORK_SUPPORT
+} GameType;
+
+typedef enum
+{
+    PLAYER_TYPE_CPU = 0,
+    PLAYER_TYPE_HUMAN = 1,
+    PLAYER_TYPE_TESTSUITE = 2,
+    PLAYER_TYPE_CPU_TEST = 3,
+#ifdef NETWORK_SUPPORT
+    PLAYER_TYPE_REMOTE = 4
+#endif //NETWORK_SUPPORT
+} PlayerType;
+
+typedef enum
+{
+    MTG_PHASE_INVALID = -1,
+    MTG_PHASE_BEFORE_BEGIN = 0,
+    MTG_PHASE_UNTAP = 1,
+    MTG_PHASE_UPKEEP = 2,
+    MTG_PHASE_DRAW = 3,
+    MTG_PHASE_FIRSTMAIN = 4,
+    MTG_PHASE_COMBATBEGIN = 5,
+    MTG_PHASE_COMBATATTACKERS = 6,
+    MTG_PHASE_COMBATBLOCKERS = 7,
+    MTG_PHASE_COMBATDAMAGE = 8,
+    MTG_PHASE_COMBATEND = 9,
+    MTG_PHASE_SECONDMAIN = 10,
+    MTG_PHASE_ENDOFTURN = 11,
+    MTG_PHASE_CLEANUP = 12,
+    MTG_PHASE_AFTER_EOT = 13,
+    NB_MTG_PHASES = 14
+} GamePhase;
+
+
 class Constants
 {
  public:
@@ -67,23 +116,6 @@ class Constants
       MTG_TYPE_LAND = 14,
       MTG_TYPE_INSTANT = 15,
 
-
-      MTG_PHASE_BEFORE_BEGIN = 0,
-      MTG_PHASE_UNTAP = 1,
-      MTG_PHASE_UPKEEP = 2,
-      MTG_PHASE_DRAW = 3,
-      MTG_PHASE_FIRSTMAIN = 4,
-      MTG_PHASE_COMBATBEGIN = 5,
-      MTG_PHASE_COMBATATTACKERS = 6,
-      MTG_PHASE_COMBATBLOCKERS = 7,
-      MTG_PHASE_COMBATDAMAGE = 8,
-      MTG_PHASE_COMBATEND = 9,
-      MTG_PHASE_SECONDMAIN = 10,
-      MTG_PHASE_ENDOFTURN = 11,
-      MTG_PHASE_CLEANUP = 12,
-      MTG_PHASE_AFTER_EOT = 13,
-      NB_MTG_PHASES = 14,
-
       TRAMPLE = 0,
       FORESTWALK = 1,
       ISLANDWALK = 2,
@@ -177,11 +209,9 @@ class Constants
       SNOWISLANDWALK = 89,
       SNOWSWAMPWALK = 90,
       CANATTACK = 91,
+      HYDRA = 92,
 
-
-
-
-      NB_BASIC_ABILITIES = 92,
+      NB_BASIC_ABILITIES = 93,
 
 
     RARITY_S = 'S',   //Special Rarity
@@ -251,7 +281,7 @@ class Constants
     };
 
   static char MTGColorChars[];
-  static const char* MTGColorStrings[];
+  static vector <const char*> MTGColorStrings;
   static int _r[], _g[], _b[];
 
   static map<string,int> MTGBasicAbilitiesMap;
@@ -261,7 +291,7 @@ class Constants
 
   static int GetBasicAbilityIndex(string mtgAbility);
   static int GetColorStringIndex(string mtgColor);
-   
+  static int NB_Colors; 
 };
 
 #endif
