@@ -14,24 +14,36 @@ using std::string;
 class SimpleMenuItem: public JGuiObject
 {
 private:
-    bool mHasFocus;
+
     SimpleMenu* parent;
-    int fontId;
-    string mText;
     float mScale;
     float mTargetScale;
+
+protected:
+    int fontId;
+    string mText;
+    bool mHasFocus;
     static float mYOffset;
+    float mXOffset;
+    
+    bool mIsValidSelection;    
+    virtual void checkUserClick();
+
 
 public:
     string desc;
+    SimpleMenuItem(int id);
     SimpleMenuItem(SimpleMenu* _parent, int id, int fontId, string text, float x, float y, bool hasFocus = false, bool autoTranslate = false);
 
     float mX;
     float mY;
 
-    void Relocate(float x, float y);
-    float GetWidth();
-    bool hasFocus();
+    
+    
+    virtual void Relocate(float x, float y);
+    virtual float GetWidth();
+    
+    virtual bool hasFocus();
 
     void RenderWithOffset(float yOffset);
     virtual void Render();
