@@ -6,20 +6,26 @@
 #include <algorithm>
 
 #define ITEM_PX_WIDTH 190.0f
+#define kItemXOffset 22
+#define kItemYHeight 30
 
 const int kHorizontalScrollSpeed = 30; // higher numbers mean faster scrolling
 
-float DeckMenuItem::mYOffset = 0;
-
-DeckMenuItem::DeckMenuItem(DeckMenu* _parent, int id, int fontId, string text, float x, float y, bool hasFocus, bool autoTranslate, DeckMetaData *deckMetaData)
-                        : JGuiObject(id), parent(_parent), fontId(fontId), mX(x), mY(y)
+DeckMenuItem::DeckMenuItem(DeckMenu* _parent, int id, int iFontId, string text, float x, float y, bool hasFocus, bool autoTranslate, DeckMetaData *deckMetaData): SimpleMenuItem(id)
 {
+    mEngine = JGE::GetInstance();
+    parent = _parent;
+    fontId = iFontId;
+    mY = y;
+    mX = x;
 	WFont * mFont = WResourceManager::Instance()->GetWFont(fontId);
     meta = deckMetaData;
 	mText = trim(text);
+    
 	if (autoTranslate)
 		mText = _(mText);	
     
+    mXOffset = kItemXOffset;
 
     mHasFocus = hasFocus;
 	float newImageWidth = 0.0f;
@@ -39,8 +45,11 @@ DeckMenuItem::DeckMenuItem(DeckMenu* _parent, int id, int fontId, string text, f
 	mScrollerOffset = 0.0f;
 
 	if (hasFocus)
+    {
+        mIsValidSelection = true;
         Entering();
-
+    }
+    
     if (meta && meta->getAvatarFilename().size() > 0)
         this->imageFilename = meta->getAvatarFilename();
     else 
@@ -67,7 +76,6 @@ DeckMenuItem::DeckMenuItem(DeckMenu* _parent, int id, int fontId, string text, f
         
     }
     
-    
 	mDisplayInitialized = false;
 
 }
@@ -82,7 +90,7 @@ void DeckMenuItem::Update(float dt)
 
 void DeckMenuItem::RenderWithOffset(float yOffset)
 {
-  mYOffset = yOffset;
+    SimpleMenuItem::mYOffset = yOffset;
 
     WFont * mFont = WResourceManager::Instance()->GetWFont(fontId);
 	
@@ -108,34 +116,51 @@ void DeckMenuItem::RenderWithOffset(float yOffset)
     }
 }
 
-void DeckMenuItem::Render()
+void DeckMenuItem::Render() 
 {
     RenderWithOffset(0);
 }
 
-void DeckMenuItem::Entering()
-{
-    mHasFocus = true;
-    parent->mSelectionTargetY = mY;
-}
-
-bool DeckMenuItem::Leaving(JButton key)
-{
-    mHasFocus = false;
-    return true;
-}
-
-bool DeckMenuItem::ButtonPressed()
-{
-    return true;
-}
-
 void DeckMenuItem::Relocate(float x, float y)
 {
     mX = x;
     mY = y;
 }
 
+void DeckMenuItem::Entering()
+{
+    checkUserClick();
+    mHasFocus = true;
+    parent->mSelectionTargetY = mY;
+}
+
+
+bool DeckMenuItem::Leaving(JButton key)
+{
+    return SimpleMenuItem::Leaving(key);
+}
+
+bool DeckMenuItem::ButtonPressed()
+{
+    return SimpleMenuItem::ButtonPressed();
+}
+
+
+void DeckMenuItem::checkUserClick()
+{
+    int x1 = -1, y1 = -1;
+    if (mEngine->GetLeftClickCoordinates(x1, y1))
+    {   
+        mIsValidSelection = false;
+        int x2 = static_cast<int>(mXOffset), y2 = static_cast<int>(mY + mYOffset);
+        if ( (x1 >= x2) && (x1 <= (x2 + 200)) && (y1 >= y2) && (y1 < (y2 + 30)))
+            mIsValidSelection = true;
+    }
+    else
+        mIsValidSelection = true;
+}
+
+// Accessors
 float DeckMenuItem::GetWidth()
 {
     WFont * mFont = WResourceManager::Instance()->GetWFont(fontId);
