@@ -1,29 +1,34 @@
 #include "PrecompiledHeader.h"
 
-#include "CardSelectorSingleton.h"
+#include "CardSelector.h"
 #include "MTGGameZones.h"
 #include "Player.h"
 #include "WEvent.h"
 #include "MTGDeck.h"
 #include "Subtypes.h"
 
+#include "Rules.h"
+#include "Token.h"
+
 #if defined (WIN32) || defined (LINUX)
 #include <time.h>
 #endif
-
 //------------------------------
 //Players Game
 //------------------------------
 
 MTGPlayerCards::MTGPlayerCards()
+    : owner(0)
 {
     init();
 }
 
-MTGPlayerCards::MTGPlayerCards(int * idList, int idListSize)
+MTGPlayerCards::MTGPlayerCards(Player* player, int * idList, int idListSize)
+    : owner(player)
 {
     init();
     int i;
+
     for (i = 0; i < idListSize; i++)
     {
         MTGCard * card = MTGCollection()->getCardById(idList[i]);
@@ -36,6 +41,7 @@ MTGPlayerCards::MTGPlayerCards(int * idList, int idListSize)
 }
 
 MTGPlayerCards::MTGPlayerCards(MTGDeck * deck)
+    : owner(0)
 {
     init();
     initDeck(deck);
@@ -117,9 +123,7 @@ void MTGPlayerCards::initGame(int shuffle, int draw)
 void MTGPlayerCards::OptimizedHand(Player * who,int amount, int lands, int creatures, int othercards)
 {
     //give the Ai hand adventage to insure a challanging match.
-    GameObserver * game = game->GetInstance();
-    game->currentPlayerId = game->currentPlayerId;
-    game->currentPlayer = game->currentPlayer;
+    GameObserver * game = who->getObserver();
 
     if (!game->players[0]->isAI() && game->players[1]->isAI())
     {
@@ -209,31 +213,14 @@ void MTGPlayerCards::drawFromLibrary()
 {
     if (!library->nb_cards)
     {
-        int cantlosers = 0;
-        MTGGameZone * z = library->owner->game->inPlay;
-        int nbcards = z->nb_cards;
-        for (int i = 0; i < nbcards; ++i)
+        if (inPlay->hasAbility(Constants::CANTLOSE)
+            || inPlay->hasAbility(Constants::CANTMILLLOSE)
+            || owner->opponent()->game->inPlay->hasAbility(Constants::CANTWIN))
         {
-            MTGCardInstance * c = z->cards[i];
-            if (c->has(Constants::CANTLOSE) || c->has(Constants::CANTMILLLOSE))
-            {
-                cantlosers++;
-            }
-        }
-        MTGGameZone * k = library->owner->opponent()->game->inPlay;
-        int onbcards = k->nb_cards;
-        for (int m = 0; m < onbcards; ++m)
-        {
-            MTGCardInstance * e = k->cards[m];
-            if (e->has(Constants::CANTWIN))
-            {
-                cantlosers++;
-            }
-        }
-        if (cantlosers < 1)
-        {
-            GameObserver::GetInstance()->gameOver = library->owner;
+            return;
         }
+
+        library->owner->getObserver()->gameOver = library->owner;
         return;
     }
     MTGCardInstance * toMove = library->cards[library->nb_cards - 1];
@@ -243,15 +230,16 @@ void MTGPlayerCards::drawFromLibrary()
     // so prefetch it.
 
     // if we're not in text mode, always get the thumb
-    if (CardSelectorSingleton::Instance()->GetDrawMode() != DrawMode::kText)
+    if (library->owner->getObserver()->getCardSelector()->GetDrawMode() != DrawMode::kText
+            && library->owner->getObserver()->getResourceManager())
     {
         DebugTrace("Prefetching AI card going into play: " << toMove->getImageName());
-        WResourceManager::Instance()->RetrieveCard(toMove, RETRIEVE_THUMB);
+        library->owner->getObserver()->getResourceManager()->RetrieveCard(toMove, RETRIEVE_THUMB);
 
         // also cache the large image if we're using kNormal mode
-        if (CardSelectorSingleton::Instance()->GetDrawMode() == DrawMode::kNormal)
+        if (library->owner->getObserver()->getCardSelector()->GetDrawMode() == DrawMode::kNormal)
         {
-            WResourceManager::Instance()->RetrieveCard(toMove);
+            library->owner->getObserver()->getResourceManager()->RetrieveCard(toMove);
         }
     }
 
@@ -316,7 +304,7 @@ MTGCardInstance * MTGPlayerCards::putInHand(MTGCardInstance * card)
 MTGCardInstance * MTGPlayerCards::putInZone(MTGCardInstance * card, MTGGameZone * from, MTGGameZone * to)
 {
     MTGCardInstance * copy = NULL;
-    GameObserver *g = GameObserver::GetInstance();
+    GameObserver *g = owner->getObserver();
     if (!from || !to)
         return card; //Error check
 
@@ -335,9 +323,9 @@ MTGCardInstance * MTGPlayerCards::putInZone(MTGCardInstance * card, MTGGameZone
     {
         if (to == g->players[0]->game->graveyard || to == g->players[1]->game->graveyard)
         {
-            if (card->isCreature())
+            if (card->isCreature() && g->getResourceManager())
             {
-                JSample * sample = WResourceManager::Instance()->RetrieveSample("graveyard.wav");
+                JSample * sample = g->getResourceManager()->RetrieveSample("graveyard.wav");
                 if (sample)
                     JSoundSystem::GetInstance()->PlaySample(sample);
             }
@@ -386,9 +374,9 @@ void MTGPlayerCards::discardRandom(MTGGameZone * from, MTGCardInstance * source)
 {
     if (!from->nb_cards)
         return;
-    int r = WRand() % (from->nb_cards);
+    int r = owner->getObserver()->getRandomGenerator()->random() % (from->nb_cards);
     WEvent * e = NEW WEventCardDiscard(from->cards[r]);
-    GameObserver * game = GameObserver::GetInstance();
+    GameObserver * game = owner->getObserver();
     game->receiveEvent(e);
     putInZone(from->cards[r], from, graveyard);
 }
@@ -420,7 +408,7 @@ MTGGameZone::MTGGameZone() :
 
 MTGGameZone::~MTGGameZone()
 {
-    for (int i = 0; i < nb_cards; i++)
+    for (size_t i = 0; i < cards.size(); i++)
     {
         SAFE_DELETE( cards[i] );
     }
@@ -440,6 +428,7 @@ void MTGGameZone::setOwner(Player * player)
     {
         cards[i]->owner = player;
         cards[i]->lastController = player;
+        cards[i]->setObserver(player->getObserver());
     }
     owner = player;
 }
@@ -462,11 +451,12 @@ MTGCardInstance * MTGGameZone::removeCard(MTGCardInstance * card, int createCopy
             //card->lastController = card->controller();
             if (createCopy)
             {
-                copy = NEW MTGCardInstance(card->model, card->owner->game);
+                copy = card->clone();
                 copy->previous = card;
                 copy->view = card->view;
                 copy->isToken = card->isToken;
                 copy->X = card->X;
+                copy->kicked = card->kicked;
 
                 //stupid bug with tokens...
                 if (card->model == card)
@@ -492,7 +482,19 @@ MTGCardInstance * MTGGameZone::hasCard(MTGCardInstance * card)
 
 }
 
-int MTGGameZone::countByType(const char * value)
+size_t MTGGameZone::getIndex(MTGCardInstance * card)
+{
+    size_t i;
+    for(i = 0; i < cards.size(); i++)
+    {
+        if(cards[i] == card)
+            return i;
+    }
+    return -1;
+}
+
+
+unsigned int MTGGameZone::countByType(const char * value)
 {
     int result = 0;
     int subTypeId = Subtypes::subtypesList->find(value);
@@ -506,10 +508,11 @@ int MTGGameZone::countByType(const char * value)
     return result;
 }
 
-int MTGGameZone::countByCanTarget(TargetChooser * tc)
+unsigned int MTGGameZone::countByCanTarget(TargetChooser * tc)
 {
-if(!tc)
-return 0;
+    if(!tc)
+        return 0;
+
     int result = 0;
     for (int i = 0; i < (nb_cards); i++)
     {
@@ -524,7 +527,7 @@ MTGCardInstance * MTGGameZone::findByName(string name)
 {
     for (int i = 0; i < (nb_cards); i++)
     {
-        if (cards[i]->name == name)
+        if (cards[i]->name == name || cards[i]->getLCName()/*tokens*/ == name)
         {
             return cards[i];
         }
@@ -646,7 +649,7 @@ int MTGGameZone::seenThisTurn(TargetChooser * tc, int castMethod)
 
 int MTGGameZone::seenThisTurn(string targetChooserDefinition, int castMethod)
 {
-    TargetChooserFactory tcf;
+    TargetChooserFactory tcf(owner->getObserver());
     TargetChooser *tc = tcf.createTargetChooser(targetChooserDefinition, NULL);
     int result = seenThisTurn(tc, castMethod);
     delete(tc);
@@ -662,7 +665,7 @@ void MTGGameZone::cleanupPhase()
 
 void MTGGameZone::shuffle()
 {
-    std::random_shuffle(cards.begin(), cards.end());
+    owner->getObserver()->getRandomGenerator()->random_shuffle(cards.begin(), cards.end());
 }
 
 void MTGGameZone::addCard(MTGCardInstance * card)
@@ -729,34 +732,6 @@ void MTGInPlay::untapAll()
     }
 }
 
-//--------------------------
-void MTGLibrary::shuffleTopToBottom(int nbcards)
-{
-    if (nbcards > nb_cards)
-        nbcards = nb_cards;
-    if (nbcards < 0)
-        return;
-    MTGCardInstance * _cards[MTG_MAX_PLAYER_CARDS];
-    for (int i = nb_cards - nbcards; i < (nb_cards); i++)
-    {
-        int r = i + (WRand() % (nbcards - i)); // Random remaining position.
-        MTGCardInstance * temp = cards[i];
-        cards[i] = cards[r];
-        cards[r] = temp;
-    }
-    for (int i = 0; i < nbcards; i++)
-    {
-        _cards[i] = cards[nb_cards - 1 - i];
-    }
-    for (int i = nbcards; i < nb_cards; i++)
-    {
-        _cards[i] = cards[i - nb_cards];
-    }
-    for (int i = 0; i < nb_cards; i++)
-    {
-        cards[i] = _cards[i];
-    }
-}
 
 MTGGameZone * MTGGameZone::intToZone(int zoneId, Player * p, Player * p2)
 {
@@ -827,16 +802,17 @@ MTGGameZone * MTGGameZone::intToZone(int zoneId, Player * p, Player * p2)
     }
 }
 
-MTGGameZone * MTGGameZone::intToZone(int zoneId, MTGCardInstance * source, MTGCardInstance * target)
+MTGGameZone * MTGGameZone::intToZone(GameObserver *g, int zoneId, MTGCardInstance * source, MTGCardInstance * target)
 {
     Player *p, *p2;
-    GameObserver * g = GameObserver::GetInstance();
+
     if (!source)
         p = g->currentlyActing();
     else
         p = source->controller();
     if (!target)
     {
+        //TODO source may be NULL, need to handle the case when it is NULL.  method declaration has NULL being default value of source and target. 
         if(source->target)
         {
         //bug case, this is a patchwork fix for now
@@ -955,9 +931,9 @@ int MTGGameZone::zoneStringToId(string zoneName)
     return 0;
 }
 
-MTGGameZone * MTGGameZone::stringToZone(string zoneName, MTGCardInstance * source, MTGCardInstance * target)
+MTGGameZone * MTGGameZone::stringToZone(GameObserver *g, string zoneName, MTGCardInstance * source, MTGCardInstance * target)
 {
-    return intToZone(zoneStringToId(zoneName), source, target);
+    return intToZone(g, zoneStringToId(zoneName), source, target);
 }
 
 ostream& MTGGameZone::toString(ostream& out) const
@@ -990,39 +966,131 @@ ostream& MTGInPlay::toString(ostream& out) const
 }
 ostream& operator<<(ostream& out, const MTGGameZone& z)
 {
-    return z.toString(out);
+    for (int i = 0; i < z.nb_cards; i++)
+    {
+        out << z.cards[i]->getMTGId();
+        if(i < z.nb_cards - 1)
+            out << ",";
+    }
+    return out;
+
+//    return z.toString(out);
 }
+
+bool MTGGameZone::parseLine(const string& ss)
+{
+    bool result = false;
+    string s = ss;
+
+    for (int i = 0; i < nb_cards; i++)
+    {
+        SAFE_DELETE( cards[i] );
+    }
+    cards.clear();
+    cardsMap.clear();
+    nb_cards = 0;
+
+    while(s.size())
+    {
+        size_t limiter = s.find(",");
+        MTGCard * card = 0;
+        string toFind;
+        if (limiter != string::npos)
+        {
+            toFind = trim(s.substr(0, limiter));
+            s = s.substr(limiter + 1);
+        }
+        else
+        {
+            toFind = trim(s);
+            s = "";
+        }
+
+        card = MTGCollection()->getCardByName(toFind);
+        int id = Rules::getMTGId(toFind);
+
+        if (card)
+        {
+            /* For the moment we add the card directly in the final zone.
+                This is not the normal way and this prevents to resolve spells.
+                We'll need a fusion operation afterward to cast relevant spells */
+            MTGCardInstance * newCard = NEW MTGCardInstance(card, owner->game);
+            addCard(newCard);
+            result = true;
+        }
+        else
+        {
+            if(toFind == "*")
+                nb_cards++;
+            else if ( id < 0 )
+            {
+                // For the moment, we create a dummy Token to please the testsuite
+                Token* myToken = new Token(id);
+                addCard(myToken);
+                result = true;
+            }
+            else
+            {
+                DebugTrace("Card unfound " << toFind << " " << id);
+            }
+        }
+    }
+
+    return result;
+}
+
 ostream& operator<<(ostream& out, const MTGPlayerCards& z)
 {
-    out << z.library->nb_cards << " ";
-    for (int i = 0; i < z.library->nb_cards; i++)
-        out << z.library->cards[i]->getMTGId() << " ";
+    if(z.library->cards.size()) {
+        out << "library=";
+        out << *(z.library) << endl;
+    }
+    if(z.battlefield->cards.size()) {
+        out << "inplay=";
+        out << *(z.battlefield) << endl;
+    }
+    if(z.graveyard->cards.size()) {
+        out << "graveyard=";
+        out << *(z.graveyard) << endl;
+    }
+    if(z.hand->cards.size()) {
+        out << "hand=";
+        out << *(z.hand) << endl;
+    }
 
     return out;
 }
 
-istream& operator>>(istream& in, MTGPlayerCards& z)
+bool MTGPlayerCards::parseLine(const string& s)
 {
-    int nb, mtgid;
-    in >> nb;
-
-    for (int i = 0; i < z.library->nb_cards; i++)
+    size_t limiter = s.find("=");
+    if (limiter == string::npos) limiter = s.find(":");
+    string areaS;
+    if (limiter != string::npos)
     {
-        SAFE_DELETE( z.library->cards[i] );
-    }
-    z.library->cards.clear();
-    z.library->cardsMap.clear();
-
-    for (int i = 0; i < nb; i++)
-    {
-        in >> mtgid;
-        MTGCard * card = MTGCollection()->getCardById(mtgid);
-        if (card)
+        areaS = s.substr(0, limiter);
+        if (areaS.compare("graveyard") == 0)
         {
-            MTGCardInstance * newCard = NEW MTGCardInstance(card, &z);
-            z.library->addCard(newCard);
+            graveyard->parseLine(s.substr(limiter+1));
+            return true;
+        }
+        else if (areaS.compare("library") == 0)
+        {
+            library->parseLine(s.substr(limiter+1));
+            return true;
+        }
+        else if (areaS.compare("hand") == 0)
+        {
+            hand->parseLine(s.substr(limiter+1));
+            return true;
+        }
+        else if (areaS.compare("inplay") == 0 || areaS.compare("battlefield") == 0)
+        {
+            battlefield->parseLine(s.substr(limiter+1));
+            return true;
         }
     }
 
-    return in;
+    return false;
 }
+
